@@ -21,10 +21,17 @@ from .contact_center_insights import (
     CreateAnalysisOperationMetadata,
     CreateAnalysisRequest,
     CreateConversationRequest,
+    CreateIssueModelMetadata,
+    CreateIssueModelRequest,
     CreatePhraseMatcherRequest,
     DeleteAnalysisRequest,
     DeleteConversationRequest,
+    DeleteIssueModelMetadata,
+    DeleteIssueModelRequest,
     DeletePhraseMatcherRequest,
+    DeployIssueModelMetadata,
+    DeployIssueModelRequest,
+    DeployIssueModelResponse,
     ExportInsightsDataMetadata,
     ExportInsightsDataRequest,
     ExportInsightsDataResponse,
@@ -44,7 +51,12 @@ from .contact_center_insights import (
     ListIssuesResponse,
     ListPhraseMatchersRequest,
     ListPhraseMatchersResponse,
+    UndeployIssueModelMetadata,
+    UndeployIssueModelRequest,
+    UndeployIssueModelResponse,
     UpdateConversationRequest,
+    UpdateIssueModelRequest,
+    UpdateIssueRequest,
     UpdateSettingsRequest,
     ConversationView,
 )
@@ -97,10 +109,17 @@ __all__ = (
     "CreateAnalysisOperationMetadata",
     "CreateAnalysisRequest",
     "CreateConversationRequest",
+    "CreateIssueModelMetadata",
+    "CreateIssueModelRequest",
     "CreatePhraseMatcherRequest",
     "DeleteAnalysisRequest",
     "DeleteConversationRequest",
+    "DeleteIssueModelMetadata",
+    "DeleteIssueModelRequest",
     "DeletePhraseMatcherRequest",
+    "DeployIssueModelMetadata",
+    "DeployIssueModelRequest",
+    "DeployIssueModelResponse",
     "ExportInsightsDataMetadata",
     "ExportInsightsDataRequest",
     "ExportInsightsDataResponse",
@@ -120,7 +139,12 @@ __all__ = (
     "ListIssuesResponse",
     "ListPhraseMatchersRequest",
     "ListPhraseMatchersResponse",
+    "UndeployIssueModelMetadata",
+    "UndeployIssueModelRequest",
+    "UndeployIssueModelResponse",
     "UpdateConversationRequest",
+    "UpdateIssueModelRequest",
+    "UpdateIssueRequest",
     "UpdateSettingsRequest",
     "ConversationView",
     "Analysis",
